﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Text.RegularExpressions;

namespace Scholarship
{
    internal class Program
    {
        // Name: Lucas Webber

        static void Main(string[] args)
        {
            // List of all available animals in the game
            List<string> animals = new List<string>
            {
                "duck",
                "goat",
                "bear",
                "lion",
                "frog",
                "deer",
                "swan",
                "wolf",
                "crab"
            };

            Random rand = new Random(); // Randomiser
            int guessesLeft = 6; // Total amount of guesses starting with
            string answer = animals[rand.Next(animals.Count)]; // The animal chosen at random
            
            //Console.WriteLine(answer); // Animal answer (for testing purposes only)

            // About the origins of Wordle and how to play the game.
            Console.WriteLine("Welcome to Animal Wordle!\r\n \r\n" +
                "Wordle is a word game that was created and developed by Welsh software engineer\r\nJosh Wardle. " +
                "In the original version of Wordle, players have six attempts to guess\r\na five-letter word, with feedback given for each guess in the form of coloured\r\ntiles indicating when letters match or occupy the correct position." +
                "\r\nIn Animal Wordle, players have six attempts to guess a four-letter animal, with\r\nfeedback given for each guess indicating when letters match or occupy the correct\r\nposition. If the character is in the correct position, it is indicated with a hash\r\n(#). " +
                "If a character is correct, but in the wrong position, it is indicated with a\r\nhyphen (-). If a character is incorrect, it is represented with a full stop (.).\r\n");


            // Enter your name
            string name;
            Console.WriteLine("Please enter your name: ");
            name = Console.ReadLine();

            // Response to you entering your name
            Console.WriteLine("\r\nHi " + name + "! " + "Would you like to play Wordle? (y/n) ");

            // This while loop will continue running if the user inputs an unknown input and can move on if 'y' or 'n' is entered
            while (true)
            {
                string question = Console.ReadLine().Trim().ToLower();

                // Breaks the while loop and plays the game
                if (question == "y")
                {
                    break;
                }

                // Closes the console
                else if (question == "n")
                {
                    Environment.Exit(0);
                }

                // Asks the question again
                else
                {
                    Console.WriteLine("\r\nInvalid Input. Please enter 'y' to play Wordle or 'n' to close the program");
                }
            }

            // Animal Wordle Game while loop
            while (true)
            {
                Console.WriteLine("\r\nYou have " + guessesLeft + " " + "guesses left.\r\n \r\nPlease enter your four-letter guess:");

                char[] guessedLetters = new char[4]; // Amount of letters
                for (int i = 0; i < 4; i++)
                {
                    Console.Write($"    Letter {i + 1}: "); // Will start at "Letter 1:" once entered it will progressively end at "Letter 4"
                    string input = Console.ReadLine();

                    // Checks to see if user inputs a single letter, if not then it prompts them with the letter again
                    if (string.IsNullOrWhiteSpace(input) || input.Length != 1 || !char.IsLetter(input[0]))
                    {
                        Console.WriteLine("Please enter a single letter");
                        i--;
                        continue;
                    }

                    // if uppercase letters were used then it translates it directly to lowercase
                    guessedLetters[i] = char.ToLower(input[0]);
                }

                guessesLeft = guessesLeft - 1; // Take away from total guesses if an incorrect word is entered

                // Feedback based on the answer given
                bool hasLetter = false;
                string feedback = "";
                for (int i = 0; i < 4; i++)
                {
                    // Correct Letter and Correct Position
                    if (guessedLetters[i] == answer[i])
                    {
                        feedback += "#"; // Chosen animal has letter and in correct position
                        hasLetter = true;
                    }

                    // Correct Letter but Incorrect Position
                    else if (answer.Contains(guessedLetters[i]))
                    {
                        feedback += "-"; // Chosen animal has letter but in wrong position
                        hasLetter = true; // If a incorrect letter has been identified then it becomes true
                    }

                    // Incorrect Letter and Incorrect Position
                    else
                    {
                        feedback += "."; // Chosen animal doesn't have this letter 
                    }
                }

                // Display feedback
                Console.WriteLine($"\r\nResult: {feedback}");

                // If the user has guessed the animal the loop breaks and prompts them to close the program
                if (new string(guessedLetters) ==  answer) 
                { 
                    Console.WriteLine("\r\nWoohoo! You guessed the word correctly!");
                    break;
                }

                // If the user has 0 guesses left, it tells them the answer, the loop breaks and prompts them to close the program
                else if (guessesLeft == 0)
                {
                    Console.WriteLine("\r\nYou have no more guesses...\r\n \r\nGame Over!");
                    Console.WriteLine("\r\nThe animal was " + answer);
                    break;
                }

                // If the user has a letter that is correct and in the correct position or a letter that is correct but in the wrong position then it gives them a comment and the loop continues
                else if (hasLetter)
                {
                    Console.WriteLine("\r\nGetting there! Keep guessing");
                }

                // If the user has no correct letters in the word it gives them a comment and the loop continues
                else
                {
                    Console.WriteLine("\r\nWhoops, no letters are correct! Keep guessing");
                }
            }

            // Prompt to close the program once the game is over
            Console.Write("\r\nPress 'Enter' or 'Return' to close the program");
            Console.Read();
        }
    }
}